from setuptools import find_packages, setup

setup(
    url='https://gitlab.com/prosocialai/proai',
    author_email='hobson@proai.org',
    name='proai',
    packages=find_packages(),
    version='0.0.1',
    description='Tools and AI for building prosocial AI algorithms.',
    author='Hobson Lane (ProAI.org)',
    license='Hippocratic License (MIT + Do No Harm)',
)
